div.window.active {
  display: block; }

div.window {
  display: none; }

input[type="hidden"] {
  display: none; }

body {
  margin: 0;
  padding: 0;
  color: white; }

ul#tabs {
  z-index: 20; }

ul#tabs li:hover {
  cursor: default; }

ul#controls {
  z-index: 30;
  background: #444444; }

body.blurred ul#controls {
  background: #333333; }

ul#controls li {
  position: relative; }

select.select_overlay {
  display: block;
  position: absolute;
  top: 0px;
  left: 0px;
  bottom: 0px;
  width: 22px;
  border: none;
  padding: 0;
  margin: 0;
  opacity: 0;
  font-size: 12px; }

select#tab_overflow_overlay option.unread {
  font-weight: bold; }

li#tab_overflow_button {
  background: url(image/sprites.png) 3px -174px no-repeat; }

li#tab_overflow_button.unread {
  background: url(image/sprites.png) 3px -194px no-repeat; }

li#config_button {
  background: url(image/sprites.png) 4px -216px no-repeat; }

body {
  font-family: "Lucida Grande", Helvetica, sans-serif;
  text-rendering: optimizeLegibility;
  background: #222222; }

a:link, a:visited, a:hover, a:active {
  color: white; }

a:hover {
  text-shadow: rgba(255, 255, 255, 0.8) 0 1px 1px; }

div.window {
  position: fixed;
  top: 0px;
  left: 0px;
  right: 0px;
  bottom: 23px; }

div.window table {
  table-layout: fixed;
  width: 100%;
  height: 100%;
  padding: 0; }

tr.input td {
  height: 20px;
  background: #333333;
  border-bottom: 1px solid #222222;
  border-top: 1px solid #444444; }

body.blurred tr.input td {
  border-bottom: 1px solid #111111; }

tr.input form {
  display: block;
  margin: 0;
  padding: 0;
  height: auto;
  line-height: 0px; }

tr.input div {
  padding: 0 3px;
  background: black;
  margin: 3px 0;
  position: relative; }

tr.input div.editor,
tr.input textarea {
  line-height: 1.2em;
  min-height: 1.2em;
  width: 100%;
  padding: 3px 0;
  border: none;
  margin: 0;
  outline: 0 none;
  font-size: 12px;
  overflow: hidden;
  resize: none;
  font-family: "Lucida Grande", Helvetica, sans-serif; }

div.editor {
  white-space: pre-wrap;
  -khtml-nbsp-mode: space; }

tr.input div.editor_toolbar {
  overflow: hidden;
  position: absolute;
  right: -170px;
  padding-right: 8px;
  top: -3px;
  width: 180px;
  height: 20px;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
  background: url(image/sprites.png) 0px -240px no-repeat black;
  z-index: 902;
  opacity: 0.2;
  -webkit-transition-property: right;
  -webkit-transition-duration: 0.3s; }

tr.input div.editor_toolbar button {
  visibility: hidden;
  display: block;
  float: left;
  color: #222222;
  line-height: 10px;
  font-size: 11px;
  margin: 0;
  padding: 4px 3px 5px 3px;
  text-align: center;
  background: none;
  cursor: pointer;
  border: none; }

tr.input div.editor_toolbar button:hover {
  color: black; }

tr.input div.editor_toolbar button.selected {
  color: yellow; }

.bold {
  font-weight: bold; }

.italic {
  font-style: italic; }

.underline {
  text-decoration: underline; }

tr.input div.editor_toolbar:hover {
  opacity: 0.4;
  cursor: pointer; }

tr.input div.editor_toolbar.visible:hover {
  opacity: 1;
  cursor: inherit; }

tr.input div.editor_toolbar.visible {
  background-color: rgba(255, 255, 255, 0.6);
  background-image: none;
  right: -4px;
  -webkit-transition-property: right;
  -webkit-transition-duration: 0.3s;
  opacity: 1; }

tr.input div.editor_toolbar.visible button {
  visibility: visible; }

div.editor div,
div.editor p,
div.editor h1,
div.editor h2,
div.editor h3,
div.editor h4,
div.editor h5,
div.editor span {
  font-size: 1em !important;
  margin: 0 !important;
  padding: 0 !important; }

div.editor img {
  display: none !important; }

tr.input input.send {
  display: none; }

div#tab_container {
  position: fixed;
  bottom: 0px;
  left: 0px;
  right: 0px;
  height: 23px;
  background: #444444; }

body.blurred div#tab_container {
  background: #333333; }

ul#tabs {
  list-style: none;
  margin: 0;
  padding: 0;
  font-size: 11px;
  position: relative;
  float: left;
  margin-right: 62px;
  padding-left: 3px; }

body.blurred ul#tabs li {
  background: #333333;
  color: #cccccc; }

ul#tabs li {
  float: left;
  margin: 0;
  margin-left: -1px;
  color: white;
  background: #444444; }

body.blurred ul#tabs li:first-child div.hit_area {
  border-left: 1px solid #333333; }

ul#tabs li:first-child div.hit_area {
  border-left: 1px solid #444444; }

ul#tabs li div.hit_area {
  border: 1px solid #222222;
  border-bottom: none;
  border-top: none;
  float: left;
  height: 14px;
  padding: 2px 10px 8px 4px; }

body.blurred ul#tabs li div.hit_area {
  border: 1px solid #111111;
  border-bottom: none;
  border-top: none; }

body.blurred ul#tabs li.active div.hit_area {
  border: 1px solid #111111;
  border-top: none; }

ul#tabs li.active div.hit_area {
  border: 1px solid #222222;
  border-top: none;
  background: #333333;
  height: 11px;
  padding-top: 3px;
  margin-top: -1px; }

ul#tabs li.active {
  height: 23px;
  z-index: 21; }

ul#tabs li.active:hover div.hit_area {
  background: #333333; }

ul#tabs li:hover div.hit_area {
  background: #3a3a3a; }

ul#controls {
  position: fixed;
  bottom: 0px;
  right: 0px;
  height: 23px;
  margin: 0;
  padding: 0 18px 0 0;
  list-style: none; }

ul#controls li {
  float: right;
  margin: 0;
  padding: 0;
  height: 16px;
  width: 16px;
  padding: 4px 3px 3px 3px;
  cursor: pointer; }

ul#controls li:hover {
  background-color: #3a3a3a; }

tr.topic td {
  width: 100%;
  background: #3a3a3a;
  font-size: 11px;
  text-align: center;
  border-top: 1px solid #666666;
  border-bottom: 1px solid black;
  padding: 1px 0;
  height: 1.2em; }

tr.topic td div.topic {
  height: 1.2em;
  overflow: hidden; }

tr.topic a {
  text-decoration: none; }

div.message_wrap {
  height: 100%;
  overflow-x: hidden;
  overflow-y: auto;
  background: #222222; }

ul.messages {
  list-style: none;
  margin: 0;
  padding: 0;
  overflow: hidden;
  margin: 3px 0; }

ul.messages > li {
  font-size: 13px;
  display: block;
  position: relative;
  background-color: #111111; }

ul.messages > li:not(.consecutive) {
  clear: both; }

ul.messages li.highlight {
  border-right: 5px solid #eb2222; }

.info ul.messages li.highlight,
ul.messages li.self {
  background: #111111;
  border-right: none; }

.info ul.messages li.highlight div.msg,
ul.messages li.self div.msg {
  background: #333333; }

ul.messages li div.msg {
  background: #222222; }

ul.messages li.consecutive div.left {
  display: none; }

div.left {
  float: left;
  width: 95px;
  font-weight: bold;
  text-align: right;
  padding: 4px 0;
  padding-right: 4px;
  padding-bottom: 0;
  text-overflow: ellipsis;
  position: relative; }

li.event a,
li.event {
  color: #cccccc; }

li.event div.left {
  padding-top: 5px; }

li.event div.msg {
  border-top: none; }

ul.messages li.avatar div.left {
  padding-bottom: 3px;
  padding-top: 3px; }

li.event div.left {
  padding: 5px 0;
  width: 95px; }

li.event div.left span.timestamp {
  opacity: 0;
  -webkit-transition: opacity 0.1s ease-in-out; }

ul.messages li.avatar:not(.consecutive) {
  z-index: 900; }

div.left img {
  border: 1px solid black;
  display: block;
  max-width: 32px;
  max-height: 32px;
  float: right; }

div.left span.nickhint {
  position: absolute;
  z-index: 901;
  right: 5px;
  top: 4px;
  padding: 0 2px;
  min-width: 28px;
  background: rgba(0, 0, 0, 0.5);
  color: #fff;
  text-shadow: black 0 1px 1px;
  opacity: 0;
  -webkit-transition: opacity 0.5s ease-in-out; }

div.timehint {
  position: absolute;
  font-size: 10px;
  right: 0px;
  top: 1px;
  padding: 6px 4px 2px 4px;
  color: #cccccc;
  opacity: 0;
  text-shadow: black 0 0 3px;
  background: #222222; }

.info ul.messages li.highlight div.timehint,
li.self div.timehint {
  background: #333333; }

div.msg {
  margin-left: 100px;
  padding: 3px 5px;
  word-wrap: break-word;
  -khtml-line-break: after-white-space;
  -khtml-nbsp-mode: space;
  border-top: 1px solid #111111;
  border-left: 1px solid black; }

li.event div.msg {
  padding: 5px; }

li.monospace div.msg {
  padding: 6px 5px; }

li.event + li.message div.msg {
  border-top: 1px solid transparent; }

ul.messages li:first-child div.msg {
  border-top: 1px solid transparent; }

/* so the last avatar doesn't hang off the edge */
ul.messages li.avatar:not(.consecutive) div.msg {
  min-height: 35px; }

ul.messages li.monospace {
  min-height: 0px; }

ul.messages li.message:last-child {
  border-bottom: 1px solid #111111; }

ul.messages li.consecutive div.msg {
  border-top: none; }

ul.messages li + li.consecutive div.msg {
  padding-top: 0px; }

div.msg a {
  word-break: break-all; }

div.msg img {
  display: block;
  border: none; }

ul.messages li.monospace + li.monospace.consecutive {
  margin-top: -5px; }

ul.messages li.monospace div.msg {
  font-family: Monaco, monospace;
  font-size: 10px;
  line-height: 12px;
  word-wrap: normal;
  white-space: pre-wrap; }

li.monospace div.msg span[style*="bold"] {
  letter-spacing: -1px; }

ul.messages li.event {
  font-size: 11px;
  background: #333333;
  border-bottom: 1px solid #111111; }

ul.messages li.event.notice {
  background: #eb2222;
  color: #fff; }

ul.messages li.event.notice a {
  color: #fffc00;
  text-decoration: none; }

ul.messages li.event.notice a:hover {
  text-shadow: none; }

ul.messages li.event.happynotice {
  background: #3fc842;
  color: #fff; }

ul.messages li.event div.msg {
  background: none;
  border-left: none; }

ul.messages li.event div.left {
  font-weight: normal; }

ul.messages li.announce div.msg {
  color: #777;
  white-space: pre-wrap; }

ul.messages li.announce div.msg ul.avatar_grid {
  margin: 0;
  padding: 0;
  list-style: none;
  width: 100%;
  overflow: hidden;
  word-wrap: normal;
  white-space: normal; }

ul.messages li.announce div.msg ul.avatar_grid li {
  width: 50px;
  height: 50px;
  float: left;
  margin: 0;
  padding: 0;
  text-align: center;
  clear: none;
  display: block;
  overflow: hidden;
  font-size: 10px;
  text-overflow: ellipsis; }

ul.messages li.announce div.msg ul.avatar_grid li div.gridimg {
  width: 32px;
  height: 32px;
  margin: 0 auto; }

ul.messages li.announce div.msg ul.avatar_grid li img {
  max-width: 32px;
  max-height: 32px;
  margin: 0 auto;
  padding: 0;
  position: relative;
  display: block; }

div.msg img.audio {
  cursor: pointer;
  display: inline;
  padding: 0 4px;
  width: 16px;
  height: 16px;
  margin-bottom: -3px; }

a.nick {
  color: white;
  text-decoration: none; }

div.tab_button {
  width: 16px;
  height: 16px;
  float: left;
  margin-right: 6px; }

li.channel_tab div.tab_button {
  background: url(image/sprites.png) 0px -80px no-repeat; }

li.privmsg_tab div.tab_button {
  background: url(image/sprites.png) 0px -120px no-repeat; }

li.info_tab div.tab_button {
  background: url(image/sprites.png) 0px 0px no-repeat; }

ul#tabs li.active div.tab_button:hover {
  background: url(image/sprites.png) 1px -260px no-repeat; }

ul#tabs li.unread.channel_tab div.tab_button {
  background: url(image/sprites.png) 0px -20px no-repeat; }

ul#tabs li.unread.privmsg_tab div.tab_button {
  background: url(image/sprites.png) 0 -100px no-repeat; }

ul#tabs li.highlight.channel_tab div.tab_button {
  background: url(image/sprites.png) 0 -40px no-repeat; }

ul#tabs li.disabled.channel_tab div.tab_button {
  background: url(image/sprites.png) 0 -60px no-repeat; }

div#logsearch {
  background: #eee;
  border-bottom: 1px solid #999;
  position: fixed;
  top: 0px;
  left: 0px;
  right: 0px;
  height: 28px;
  padding: 5px 0 0 0; }

div#logsearch label {
  font-size: 0.7em;
  padding-right: 2px;
  padding-left: 10px;
  color: #666; }

div#logsearch form {
  display: block;
  margin: 0; }

ul#logresults {
  list-style: none;
  margin: 0;
  padding: 0;
  position: absolute;
  top: 34px;
  bottom: 0px;
  left: 0px;
  right: 0px;
  overflow: auto; }

ul#logresults li {
  border-bottom: 1px solid #eee;
  padding: 0;
  font-size: 0.8em;
  cursor: pointer; }

ul#logresults div.focus:hover {
  background: #eee; }

ul#logresults li div.focus {
  background: #fff;
  padding: 5px 10px; }

ul#logresults li.context div.focus:hover {
  background: #fff; }

ul#logresults li.context ul {
  margin: 0;
  padding: 5px 10px;
  list-style: none; }

ul#logresults li.context ul li {
  border: none;
  margin: 0;
  padding: 2px 0; }

ul#logresults li.context {
  border-top: 1px solid #999;
  border-bottom: 1px solid #999;
  background: url(image/shadow-bottom.png) bottom left repeat-x, url(image/shadow-top.png) top left repeat-x #eeeeee; }

ul#logresults span.metadata {
  font-size: 0.7em;
  color: #666; }

div#help {
  position: absolute;
  z-index: 999;
  background: rgba(0, 0, 0, 0.8);
  color: #fff;
  left: 20px;
  right: 20px;
  top: 25px;
  bottom: 60px;
  padding: 10px 20px;
  -webkit-border-radius: 10px;
  -moz-border-radius: 10px;
  border-radius: 10px;
  text-shadow: 0 0 3px rgba(0, 0, 0, 0.9); }

div#help div#helpclose {
  position: absolute;
  top: 17px;
  right: 20px;
  color: rgba(255, 255, 255, 0.75);
  font-size: 9px;
  letter-spacing: 1px;
  text-shadow: none;
  text-transform: uppercase; }

div#help div#helpclose:hover {
  cursor: pointer;
  color: #fff; }

div#help div#topics {
  position: absolute;
  top: 34px;
  bottom: 15px;
  left: 20px;
  right: 20px;
  overflow-y: auto; }

div#help h1 {
  margin: 0;
  font-size: 20px;
  border-bottom: 1px solid #999;
  font-weight: normal; }

div#help dl {
  width: 48%;
  font-size: 12px;
  margin-top: 0;
  padding-top: 10px;
  float: left;
  display: block;
  border-right: 1px solid #666;
  padding-right: 2%; }

div#help dl#shortcuts {
  border-right: none;
  float: right;
  padding-right: 0;
  padding-left: 2%; }

div#help h2 {
  color: yellow;
  margin-top: 0;
  font-weight: normal; }

div#help dt {
  font-weight: bold; }

div#help dd {
  font-weight: normal;
  margin: 0;
  margin-bottom: 10px; }

div.color_picker {
  position: absolute;
  right: 25px;
  bottom: 27px;
  width: 80px;
  border-bottom: none;
  margin: 0;
  padding: 0;
  z-index: 903; }

div.color_picker span {
  cursor: pointer; }

div.color_picker div.colors {
  clear: both; }

div.color_picker div.colors span {
  float: left;
  display: block;
  width: 20px;
  height: 20px;
  margin: 0;
  -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.6);
  -moz-box-shadow: 0 0 3px rgba(0, 0, 0, 0.6);
  box-shadow: 0 0 3px rgba(0, 0, 0, 0.6); }

div.color_picker div.toggle {
  height: 18px; }

div.color_picker div.toggle span.blank {
  float: right;
  color: red;
  font-weight: bold;
  text-align: center;
  width: 20px;
  line-height: 9px; }

div.color_picker div.toggle span#fg,
div.color_picker div.toggle span#bg {
  float: left;
  font-size: 9px;
  background: none;
  -webkit-border-radius: 10px;
  -moz-border-radius: 10px;
  border-radius: 10px;
  color: white;
  text-align: center;
  padding: 2px 5px; }

div.color_picker div.toggle span#fg.active,
div.color_picker div.toggle span#bg.active {
  background: rgba(255, 255, 255, 0.6);
  color: black; }

@media screen and (max-device-width: 480px) {
  div.left {
    width: 40px !important; }

  div.msg {
    margin-left: 52px !important; }

  div.topic {
    height: 1.2em;
    overflow: hidden; }

  tr.input div {
    margin-right: 55px;
    background: none; }

  tr.input input.send {
    display: block;
    position: absolute;
    bottom: 2px;
    right: 0px;
    z-index: 999; }

  div.msg.monospace, div.msg.announce {
    line-height: 11px; } }

div.config {
  position: absolute;
  bottom: 55px;
  right: 20px;
  background: #efefef;
  padding: 10px 10px;
  z-index: 999;
  border: 10px solid rgba(0, 0, 0, 0.5);
  -webkit-border-radius: 10px;
  -moz-border-radius: 5px;
  border-radius: 5px; }

div.config div.buttons {
  clear: both; }

div.config div.buttons button {
  float: right; }

div.config div.setting {
  margin-top: 0.5em;
  margin-left: 160px;
  display: none; }

div.config div.setting.active {
  display: block; }

div.config div.field {
  float: left;
  margin-bottom: 10px;
  margin-right: 8px; }

div.config div.field.clear {
  clear: both; }

div.config label, div.config input {
  display: block;
  font-size: 0.8em; }

div.config span {
  font-size: 0.8em; }

div.config select {
  width: 135px;
  font-size: 0.8em;
  outline: 0 none; }

div.config[multiple] {
  height: 100px; }

div.config div#server_controls {
  position: absolute;
  bottom: 18px;
  left: 6px; }

div.config div.controls {
  clear: both;
  font-size: 0.7em; }

div.config div.controls a {
  text-decoration: none;
  margin: 0 5px 0 0; }

div.config div.controls a:hover {
  text-shadow: none;
  text-decoration: underline; }

div.config label {
  color: #666; }

div.config input[type="checkbox"] {
  float: left;
  margin-right: 4px; }

div.config ul#connections {
  list-style: none;
  position: absolute;
  top: 5px;
  bottom: 32px;
  left: 5px;
  margin: 0;
  padding: 0px;
  width: 150px;
  background: #fff;
  border-right: 1px solid #ccc;
  border-bottom: 1px solid #ccc; }

div.config ul#connections li.header {
  background: #efefef;
  text-transform: uppercase;
  color: #777;
  letter-spacing: 1px;
  font-size: 0.7em;
  cursor: default; }

div.config ul#connections li.header:hover {
  background: #efefef; }

div.config ul#connections li {
  padding: 5px 8px;
  font-size: 0.9em;
  cursor: pointer;
  border: 1px solid #fff;
  border-bottom: none; }

div.config ul#connections li:hover {
  background: #ffffcc; }

div.config ul#connections li.disconnected.active,
div.config ul#connections li.connected.active {
  background: #3875d7;
  color: #fff; }

div.config ul#connections li.disconnected {
  color: #999; }

div.config ul#connections li.connected {
  color: #222; }

body.config {
  background: #efefef; }
